@@ -1,7 +1,8 @@
-from typing import ClassVar, Dict, List, Optional
+from typing import ClassVar, List, Optional
 
 from pycfmodel.model.base import CustomModel
 from pycfmodel.model.resources.properties.policy_document import PolicyDocument
+from pycfmodel.model.resources.properties.tag import Tag
 from pycfmodel.model.resources.resource import Resource
 from pycfmodel.model.types import Resolvable, ResolvableBool, ResolvableInt, ResolvableStr
 from pycfmodel.model.utils import OptionallyNamedPolicyDocument
@@ -16,6 +17,8 @@ class KMSKeyProperties(CustomModel):
     - Enabled: Specifies whether the customer master key (CMK) is enabled.
     - KeyPolicy: A [policy document][pycfmodel.model.resources.properties.policy_document.PolicyDocument] object.
     - KeyUsage: Determines the cryptographic operations.
+    - KeySpec: Specifies the type of CMK to create.
+    - MultiRegion: Allows multi-Region primary CMK to be replicated in other AWS Regions.
     - PendingWindowInDays: Number of days in the waiting period before AWS KMS deletes a CMK that has been removed from a CloudFormation stack.
     - Tags: Array of key-value pairs.
 
@@ -27,8 +30,10 @@ class KMSKeyProperties(CustomModel):
     Enabled: Optional[ResolvableBool] = None
     KeyPolicy: Resolvable[PolicyDocument]
     KeyUsage: Optional[ResolvableStr] = None
+    KeySpec: Optional[ResolvableStr] = None
+    MultiRegion: Optional[ResolvableBool] = None
     PendingWindowInDays: Optional[ResolvableInt] = None
-    Tags: Optional[Resolvable[List[Dict]]] = None
+    Tags: Optional[Resolvable[List[Tag]]] = None
 
 
 class KMSKey(Resource):
